class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QNdefFilter():
    """"""
    def __init__(self):
        '''void QNdefFilter.__init__()'''
    def __init__(self, other):
        '''void QNdefFilter.__init__(QNdefFilter other)'''
    def recordAt(self, i):
        '''QNdefFilter.Record QNdefFilter.recordAt(int i)'''
        return QNdefFilter.Record()
    def __len__(self):
        ''' QNdefFilter.__len__()'''
        return ()
    def recordCount(self):
        '''int QNdefFilter.recordCount()'''
        return int()
    def appendRecord(self, typeNameFormat, type, min = 1, max = 1):
        '''void QNdefFilter.appendRecord(QNdefRecord.TypeNameFormat typeNameFormat, QByteArray type, int min = 1, int max = 1)'''
    def appendRecord(self, record):
        '''void QNdefFilter.appendRecord(QNdefFilter.Record record)'''
    def orderMatch(self):
        '''bool QNdefFilter.orderMatch()'''
        return bool()
    def setOrderMatch(self, on):
        '''void QNdefFilter.setOrderMatch(bool on)'''
    def clear(self):
        '''void QNdefFilter.clear()'''
    class Record():
        """"""
        maximum = None # int - member
        minimum = None # int - member
        type = None # QByteArray - member
        typeNameFormat = None # QNdefRecord.TypeNameFormat - member
        def __init__(self):
            '''void QNdefFilter.Record.__init__()'''
        def __init__(self):
            '''QNdefFilter.Record QNdefFilter.Record.__init__()'''
            return QNdefFilter.Record()


class QNdefMessage():
    """"""
    def __init__(self):
        '''void QNdefMessage.__init__()'''
    def __init__(self, record):
        '''void QNdefMessage.__init__(QNdefRecord record)'''
    def __init__(self, message):
        '''void QNdefMessage.__init__(QNdefMessage message)'''
    def __init__(self, records):
        '''void QNdefMessage.__init__(list-of-QNdefRecord records)'''
    def __ne__(self, other):
        '''bool QNdefMessage.__ne__(QNdefMessage other)'''
        return bool()
    def fromByteArray(self, message):
        '''static QNdefMessage QNdefMessage.fromByteArray(QByteArray message)'''
        return QNdefMessage()
    def __delitem__(self, i):
        '''void QNdefMessage.__delitem__(int i)'''
    def __setitem__(self, i, value):
        '''void QNdefMessage.__setitem__(int i, QNdefRecord value)'''
    def __getitem__(self, i):
        '''QNdefRecord QNdefMessage.__getitem__(int i)'''
        return QNdefRecord()
    def __len__(self):
        '''int QNdefMessage.__len__()'''
        return int()
    def toByteArray(self):
        '''QByteArray QNdefMessage.toByteArray()'''
        return QByteArray()
    def __eq__(self, other):
        '''bool QNdefMessage.__eq__(QNdefMessage other)'''
        return bool()


class QNdefRecord():
    """"""
    # Enum QNdefRecord.TypeNameFormat
    Empty = 0
    NfcRtd = 0
    Mime = 0
    Uri = 0
    ExternalRtd = 0
    Unknown = 0

    def __init__(self):
        '''void QNdefRecord.__init__()'''
    def __init__(self, other):
        '''void QNdefRecord.__init__(QNdefRecord other)'''
    def __hash__(self):
        '''int QNdefRecord.__hash__()'''
        return int()
    def __ne__(self, other):
        '''bool QNdefRecord.__ne__(QNdefRecord other)'''
        return bool()
    def __eq__(self, other):
        '''bool QNdefRecord.__eq__(QNdefRecord other)'''
        return bool()
    def isEmpty(self):
        '''bool QNdefRecord.isEmpty()'''
        return bool()
    def payload(self):
        '''QByteArray QNdefRecord.payload()'''
        return QByteArray()
    def setPayload(self, payload):
        '''void QNdefRecord.setPayload(QByteArray payload)'''
    def id(self):
        '''QByteArray QNdefRecord.id()'''
        return QByteArray()
    def setId(self, id):
        '''void QNdefRecord.setId(QByteArray id)'''
    def type(self):
        '''QByteArray QNdefRecord.type()'''
        return QByteArray()
    def setType(self, type):
        '''void QNdefRecord.setType(QByteArray type)'''
    def typeNameFormat(self):
        '''QNdefRecord.TypeNameFormat QNdefRecord.typeNameFormat()'''
        return QNdefRecord.TypeNameFormat()
    def setTypeNameFormat(self, typeNameFormat):
        '''void QNdefRecord.setTypeNameFormat(QNdefRecord.TypeNameFormat typeNameFormat)'''


class QNdefNfcIconRecord(QNdefRecord):
    """"""
    def __init__(self):
        '''void QNdefNfcIconRecord.__init__()'''
    def __init__(self, other):
        '''void QNdefNfcIconRecord.__init__(QNdefRecord other)'''
    def __init__(self):
        '''QNdefNfcIconRecord QNdefNfcIconRecord.__init__()'''
        return QNdefNfcIconRecord()
    def data(self):
        '''QByteArray QNdefNfcIconRecord.data()'''
        return QByteArray()
    def setData(self, data):
        '''void QNdefNfcIconRecord.setData(QByteArray data)'''


class QNdefNfcSmartPosterRecord(QNdefRecord):
    """"""
    # Enum QNdefNfcSmartPosterRecord.Action
    UnspecifiedAction = 0
    DoAction = 0
    SaveAction = 0
    EditAction = 0

    def __init__(self):
        '''void QNdefNfcSmartPosterRecord.__init__()'''
    def __init__(self, other):
        '''void QNdefNfcSmartPosterRecord.__init__(QNdefNfcSmartPosterRecord other)'''
    def __init__(self, other):
        '''void QNdefNfcSmartPosterRecord.__init__(QNdefRecord other)'''
    def setTypeInfo(self, type):
        '''void QNdefNfcSmartPosterRecord.setTypeInfo(QByteArray type)'''
    def typeInfo(self):
        '''QByteArray QNdefNfcSmartPosterRecord.typeInfo()'''
        return QByteArray()
    def setSize(self, size):
        '''void QNdefNfcSmartPosterRecord.setSize(int size)'''
    def size(self):
        '''int QNdefNfcSmartPosterRecord.size()'''
        return int()
    def setIcons(self, icons):
        '''void QNdefNfcSmartPosterRecord.setIcons(list-of-QNdefNfcIconRecord icons)'''
    def removeIcon(self, icon):
        '''bool QNdefNfcSmartPosterRecord.removeIcon(QNdefNfcIconRecord icon)'''
        return bool()
    def removeIcon(self, type):
        '''bool QNdefNfcSmartPosterRecord.removeIcon(QByteArray type)'''
        return bool()
    def addIcon(self, icon):
        '''void QNdefNfcSmartPosterRecord.addIcon(QNdefNfcIconRecord icon)'''
    def addIcon(self, type, data):
        '''void QNdefNfcSmartPosterRecord.addIcon(QByteArray type, QByteArray data)'''
    def iconRecords(self):
        '''list-of-QNdefNfcIconRecord QNdefNfcSmartPosterRecord.iconRecords()'''
        return [QNdefNfcIconRecord()]
    def iconRecord(self, index):
        '''QNdefNfcIconRecord QNdefNfcSmartPosterRecord.iconRecord(int index)'''
        return QNdefNfcIconRecord()
    def icon(self, mimetype = QByteArray()):
        '''QByteArray QNdefNfcSmartPosterRecord.icon(QByteArray mimetype = QByteArray())'''
        return QByteArray()
    def iconCount(self):
        '''int QNdefNfcSmartPosterRecord.iconCount()'''
        return int()
    def setAction(self, act):
        '''void QNdefNfcSmartPosterRecord.setAction(QNdefNfcSmartPosterRecord.Action act)'''
    def action(self):
        '''QNdefNfcSmartPosterRecord.Action QNdefNfcSmartPosterRecord.action()'''
        return QNdefNfcSmartPosterRecord.Action()
    def setUri(self, url):
        '''void QNdefNfcSmartPosterRecord.setUri(QNdefNfcUriRecord url)'''
    def setUri(self, url):
        '''void QNdefNfcSmartPosterRecord.setUri(QUrl url)'''
    def uriRecord(self):
        '''QNdefNfcUriRecord QNdefNfcSmartPosterRecord.uriRecord()'''
        return QNdefNfcUriRecord()
    def uri(self):
        '''QUrl QNdefNfcSmartPosterRecord.uri()'''
        return QUrl()
    def setTitles(self, titles):
        '''void QNdefNfcSmartPosterRecord.setTitles(list-of-QNdefNfcTextRecord titles)'''
    def removeTitle(self, text):
        '''bool QNdefNfcSmartPosterRecord.removeTitle(QNdefNfcTextRecord text)'''
        return bool()
    def removeTitle(self, locale):
        '''bool QNdefNfcSmartPosterRecord.removeTitle(str locale)'''
        return bool()
    def addTitle(self, text):
        '''bool QNdefNfcSmartPosterRecord.addTitle(QNdefNfcTextRecord text)'''
        return bool()
    def addTitle(self, text, locale, encoding):
        '''bool QNdefNfcSmartPosterRecord.addTitle(str text, str locale, QNdefNfcTextRecord.Encoding encoding)'''
        return bool()
    def titleRecords(self):
        '''list-of-QNdefNfcTextRecord QNdefNfcSmartPosterRecord.titleRecords()'''
        return [QNdefNfcTextRecord()]
    def titleRecord(self, index):
        '''QNdefNfcTextRecord QNdefNfcSmartPosterRecord.titleRecord(int index)'''
        return QNdefNfcTextRecord()
    def title(self, locale = str()):
        '''str QNdefNfcSmartPosterRecord.title(str locale = str())'''
        return str()
    def titleCount(self):
        '''int QNdefNfcSmartPosterRecord.titleCount()'''
        return int()
    def hasTypeInfo(self):
        '''bool QNdefNfcSmartPosterRecord.hasTypeInfo()'''
        return bool()
    def hasSize(self):
        '''bool QNdefNfcSmartPosterRecord.hasSize()'''
        return bool()
    def hasIcon(self, mimetype = QByteArray()):
        '''bool QNdefNfcSmartPosterRecord.hasIcon(QByteArray mimetype = QByteArray())'''
        return bool()
    def hasAction(self):
        '''bool QNdefNfcSmartPosterRecord.hasAction()'''
        return bool()
    def hasTitle(self, locale = str()):
        '''bool QNdefNfcSmartPosterRecord.hasTitle(str locale = str())'''
        return bool()
    def setPayload(self, payload):
        '''void QNdefNfcSmartPosterRecord.setPayload(QByteArray payload)'''


class QNdefNfcTextRecord(QNdefRecord):
    """"""
    # Enum QNdefNfcTextRecord.Encoding
    Utf8 = 0
    Utf16 = 0

    def __init__(self):
        '''void QNdefNfcTextRecord.__init__()'''
    def __init__(self, other):
        '''void QNdefNfcTextRecord.__init__(QNdefRecord other)'''
    def __init__(self):
        '''QNdefNfcTextRecord QNdefNfcTextRecord.__init__()'''
        return QNdefNfcTextRecord()
    def setEncoding(self, encoding):
        '''void QNdefNfcTextRecord.setEncoding(QNdefNfcTextRecord.Encoding encoding)'''
    def encoding(self):
        '''QNdefNfcTextRecord.Encoding QNdefNfcTextRecord.encoding()'''
        return QNdefNfcTextRecord.Encoding()
    def setText(self, text):
        '''void QNdefNfcTextRecord.setText(str text)'''
    def text(self):
        '''str QNdefNfcTextRecord.text()'''
        return str()
    def setLocale(self, locale):
        '''void QNdefNfcTextRecord.setLocale(str locale)'''
    def locale(self):
        '''str QNdefNfcTextRecord.locale()'''
        return str()


class QNdefNfcUriRecord(QNdefRecord):
    """"""
    def __init__(self):
        '''void QNdefNfcUriRecord.__init__()'''
    def __init__(self, other):
        '''void QNdefNfcUriRecord.__init__(QNdefRecord other)'''
    def __init__(self):
        '''QNdefNfcUriRecord QNdefNfcUriRecord.__init__()'''
        return QNdefNfcUriRecord()
    def setUri(self, uri):
        '''void QNdefNfcUriRecord.setUri(QUrl uri)'''
    def uri(self):
        '''QUrl QNdefNfcUriRecord.uri()'''
        return QUrl()


class QNearFieldManager(QObject):
    """"""
    # Enum QNearFieldManager.TargetAccessMode
    NoTargetAccess = 0
    NdefReadTargetAccess = 0
    NdefWriteTargetAccess = 0
    TagTypeSpecificTargetAccess = 0

    def __init__(self, parent = None):
        '''void QNearFieldManager.__init__(QObject parent = None)'''
    targetLost = pyqtSignal() # void targetLost(QNearFieldTarget*) - signal
    targetDetected = pyqtSignal() # void targetDetected(QNearFieldTarget*) - signal
    def unregisterNdefMessageHandler(self, handlerId):
        '''bool QNearFieldManager.unregisterNdefMessageHandler(int handlerId)'''
        return bool()
    def registerNdefMessageHandler(self, slot):
        '''int QNearFieldManager.registerNdefMessageHandler(slot slot)'''
        return int()
    def registerNdefMessageHandler(self, typeNameFormat, type, slot):
        '''int QNearFieldManager.registerNdefMessageHandler(QNdefRecord.TypeNameFormat typeNameFormat, QByteArray type, slot slot)'''
        return int()
    def registerNdefMessageHandler(self, filter, slot):
        '''int QNearFieldManager.registerNdefMessageHandler(QNdefFilter filter, slot slot)'''
        return int()
    def stopTargetDetection(self):
        '''void QNearFieldManager.stopTargetDetection()'''
    def startTargetDetection(self):
        '''bool QNearFieldManager.startTargetDetection()'''
        return bool()
    def targetAccessModes(self):
        '''QNearFieldManager.TargetAccessModes QNearFieldManager.targetAccessModes()'''
        return QNearFieldManager.TargetAccessModes()
    def setTargetAccessModes(self, accessModes):
        '''void QNearFieldManager.setTargetAccessModes(QNearFieldManager.TargetAccessModes accessModes)'''
    def isAvailable(self):
        '''bool QNearFieldManager.isAvailable()'''
        return bool()
    class TargetAccessModes():
        """"""
        def __init__(self):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__init__()'''
            return QNearFieldManager.TargetAccessModes()
        def __init__(self):
            '''int QNearFieldManager.TargetAccessModes.__init__()'''
            return int()
        def __init__(self):
            '''void QNearFieldManager.TargetAccessModes.__init__()'''
        def __bool__(self):
            '''int QNearFieldManager.TargetAccessModes.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QNearFieldManager.TargetAccessModes.__ne__(QNearFieldManager.TargetAccessModes f)'''
            return bool()
        def __eq__(self, f):
            '''bool QNearFieldManager.TargetAccessModes.__eq__(QNearFieldManager.TargetAccessModes f)'''
            return bool()
        def __invert__(self):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__invert__()'''
            return QNearFieldManager.TargetAccessModes()
        def __and__(self, mask):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__and__(int mask)'''
            return QNearFieldManager.TargetAccessModes()
        def __xor__(self, f):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__xor__(QNearFieldManager.TargetAccessModes f)'''
            return QNearFieldManager.TargetAccessModes()
        def __xor__(self, f):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__xor__(int f)'''
            return QNearFieldManager.TargetAccessModes()
        def __or__(self, f):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__or__(QNearFieldManager.TargetAccessModes f)'''
            return QNearFieldManager.TargetAccessModes()
        def __or__(self, f):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__or__(int f)'''
            return QNearFieldManager.TargetAccessModes()
        def __int__(self):
            '''int QNearFieldManager.TargetAccessModes.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__ixor__(QNearFieldManager.TargetAccessModes f)'''
            return QNearFieldManager.TargetAccessModes()
        def __ior__(self, f):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__ior__(QNearFieldManager.TargetAccessModes f)'''
            return QNearFieldManager.TargetAccessModes()
        def __iand__(self, mask):
            '''QNearFieldManager.TargetAccessModes QNearFieldManager.TargetAccessModes.__iand__(int mask)'''
            return QNearFieldManager.TargetAccessModes()


class QNearFieldShareManager(QObject):
    """"""
    # Enum QNearFieldShareManager.ShareMode
    NoShare = 0
    NdefShare = 0
    FileShare = 0

    # Enum QNearFieldShareManager.ShareError
    NoError = 0
    UnknownError = 0
    InvalidShareContentError = 0
    ShareCanceledError = 0
    ShareInterruptedError = 0
    ShareRejectedError = 0
    UnsupportedShareModeError = 0
    ShareAlreadyInProgressError = 0
    SharePermissionDeniedError = 0

    def __init__(self, parent = None):
        '''void QNearFieldShareManager.__init__(QObject parent = None)'''
    error = pyqtSignal() # void error(QNearFieldShareManager::ShareError) - signal
    shareModesChanged = pyqtSignal() # void shareModesChanged(QNearFieldShareManager::ShareModes) - signal
    targetDetected = pyqtSignal() # void targetDetected(QNearFieldShareTarget*) - signal
    def shareError(self):
        '''QNearFieldShareManager.ShareError QNearFieldShareManager.shareError()'''
        return QNearFieldShareManager.ShareError()
    def shareModes(self):
        '''QNearFieldShareManager.ShareModes QNearFieldShareManager.shareModes()'''
        return QNearFieldShareManager.ShareModes()
    def setShareModes(self, modes):
        '''void QNearFieldShareManager.setShareModes(QNearFieldShareManager.ShareModes modes)'''
    def supportedShareModes(self):
        '''static QNearFieldShareManager.ShareModes QNearFieldShareManager.supportedShareModes()'''
        return QNearFieldShareManager.ShareModes()
    class ShareModes():
        """"""
        def __init__(self):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__init__()'''
            return QNearFieldShareManager.ShareModes()
        def __init__(self):
            '''int QNearFieldShareManager.ShareModes.__init__()'''
            return int()
        def __init__(self):
            '''void QNearFieldShareManager.ShareModes.__init__()'''
        def __bool__(self):
            '''int QNearFieldShareManager.ShareModes.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QNearFieldShareManager.ShareModes.__ne__(QNearFieldShareManager.ShareModes f)'''
            return bool()
        def __eq__(self, f):
            '''bool QNearFieldShareManager.ShareModes.__eq__(QNearFieldShareManager.ShareModes f)'''
            return bool()
        def __invert__(self):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__invert__()'''
            return QNearFieldShareManager.ShareModes()
        def __and__(self, mask):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__and__(int mask)'''
            return QNearFieldShareManager.ShareModes()
        def __xor__(self, f):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__xor__(QNearFieldShareManager.ShareModes f)'''
            return QNearFieldShareManager.ShareModes()
        def __xor__(self, f):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__xor__(int f)'''
            return QNearFieldShareManager.ShareModes()
        def __or__(self, f):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__or__(QNearFieldShareManager.ShareModes f)'''
            return QNearFieldShareManager.ShareModes()
        def __or__(self, f):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__or__(int f)'''
            return QNearFieldShareManager.ShareModes()
        def __int__(self):
            '''int QNearFieldShareManager.ShareModes.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__ixor__(QNearFieldShareManager.ShareModes f)'''
            return QNearFieldShareManager.ShareModes()
        def __ior__(self, f):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__ior__(QNearFieldShareManager.ShareModes f)'''
            return QNearFieldShareManager.ShareModes()
        def __iand__(self, mask):
            '''QNearFieldShareManager.ShareModes QNearFieldShareManager.ShareModes.__iand__(int mask)'''
            return QNearFieldShareManager.ShareModes()


class QNearFieldShareTarget(QObject):
    """"""
    shareFinished = pyqtSignal() # void shareFinished() - signal
    error = pyqtSignal() # void error(QNearFieldShareManager::ShareError) - signal
    def shareError(self):
        '''QNearFieldShareManager.ShareError QNearFieldShareTarget.shareError()'''
        return QNearFieldShareManager.ShareError()
    def isShareInProgress(self):
        '''bool QNearFieldShareTarget.isShareInProgress()'''
        return bool()
    def cancel(self):
        '''void QNearFieldShareTarget.cancel()'''
    def share(self, message):
        '''bool QNearFieldShareTarget.share(QNdefMessage message)'''
        return bool()
    def share(self, files):
        '''bool QNearFieldShareTarget.share(list-of-QFileInfo files)'''
        return bool()
    def shareModes(self):
        '''QNearFieldShareManager.ShareModes QNearFieldShareTarget.shareModes()'''
        return QNearFieldShareManager.ShareModes()


class QNearFieldTarget(QObject):
    """"""
    # Enum QNearFieldTarget.Error
    NoError = 0
    UnknownError = 0
    UnsupportedError = 0
    TargetOutOfRangeError = 0
    NoResponseError = 0
    ChecksumMismatchError = 0
    InvalidParametersError = 0
    NdefReadError = 0
    NdefWriteError = 0

    # Enum QNearFieldTarget.AccessMethod
    UnknownAccess = 0
    NdefAccess = 0
    TagTypeSpecificAccess = 0
    LlcpAccess = 0

    # Enum QNearFieldTarget.Type
    ProprietaryTag = 0
    NfcTagType1 = 0
    NfcTagType2 = 0
    NfcTagType3 = 0
    NfcTagType4 = 0
    MifareTag = 0

    def __init__(self, parent = None):
        '''void QNearFieldTarget.__init__(QObject parent = None)'''
    error = pyqtSignal() # void error(QNearFieldTarget::Error,const QNearFieldTarget::RequestIdamp;) - signal
    requestCompleted = pyqtSignal() # void requestCompleted(const QNearFieldTarget::RequestIdamp;) - signal
    ndefMessagesWritten = pyqtSignal() # void ndefMessagesWritten() - signal
    ndefMessageRead = pyqtSignal() # void ndefMessageRead(const QNdefMessageamp;) - signal
    disconnected = pyqtSignal() # void disconnected() - signal
    def handleResponse(self, id, response):
        '''bool QNearFieldTarget.handleResponse(QNearFieldTarget.RequestId id, QByteArray response)'''
        return bool()
    def setResponseForRequest(self, id, response, emitRequestCompleted = True):
        '''void QNearFieldTarget.setResponseForRequest(QNearFieldTarget.RequestId id, QVariant response, bool emitRequestCompleted = True)'''
    def requestResponse(self, id):
        '''QVariant QNearFieldTarget.requestResponse(QNearFieldTarget.RequestId id)'''
        return QVariant()
    def waitForRequestCompleted(self, id, msecs = 5000):
        '''bool QNearFieldTarget.waitForRequestCompleted(QNearFieldTarget.RequestId id, int msecs = 5000)'''
        return bool()
    def sendCommands(self, commands):
        '''QNearFieldTarget.RequestId QNearFieldTarget.sendCommands(list-of-QByteArray commands)'''
        return QNearFieldTarget.RequestId()
    def sendCommand(self, command):
        '''QNearFieldTarget.RequestId QNearFieldTarget.sendCommand(QByteArray command)'''
        return QNearFieldTarget.RequestId()
    def writeNdefMessages(self, messages):
        '''QNearFieldTarget.RequestId QNearFieldTarget.writeNdefMessages(list-of-QNdefMessage messages)'''
        return QNearFieldTarget.RequestId()
    def readNdefMessages(self):
        '''QNearFieldTarget.RequestId QNearFieldTarget.readNdefMessages()'''
        return QNearFieldTarget.RequestId()
    def hasNdefMessage(self):
        '''bool QNearFieldTarget.hasNdefMessage()'''
        return bool()
    def isProcessingCommand(self):
        '''bool QNearFieldTarget.isProcessingCommand()'''
        return bool()
    def accessMethods(self):
        '''abstract QNearFieldTarget.AccessMethods QNearFieldTarget.accessMethods()'''
        return QNearFieldTarget.AccessMethods()
    def type(self):
        '''abstract QNearFieldTarget.Type QNearFieldTarget.type()'''
        return QNearFieldTarget.Type()
    def url(self):
        '''QUrl QNearFieldTarget.url()'''
        return QUrl()
    def uid(self):
        '''abstract QByteArray QNearFieldTarget.uid()'''
        return QByteArray()
    class RequestId():
        """"""
        def __init__(self):
            '''void QNearFieldTarget.RequestId.__init__()'''
        def __init__(self, other):
            '''void QNearFieldTarget.RequestId.__init__(QNearFieldTarget.RequestId other)'''
        def __ge__(self, other):
            '''bool QNearFieldTarget.RequestId.__ge__(QNearFieldTarget.RequestId other)'''
            return bool()
        def __ne__(self, other):
            '''bool QNearFieldTarget.RequestId.__ne__(QNearFieldTarget.RequestId other)'''
            return bool()
        def __eq__(self, other):
            '''bool QNearFieldTarget.RequestId.__eq__(QNearFieldTarget.RequestId other)'''
            return bool()
        def __lt__(self, other):
            '''bool QNearFieldTarget.RequestId.__lt__(QNearFieldTarget.RequestId other)'''
            return bool()
        def refCount(self):
            '''int QNearFieldTarget.RequestId.refCount()'''
            return int()
        def isValid(self):
            '''bool QNearFieldTarget.RequestId.isValid()'''
            return bool()
    class AccessMethods():
        """"""
        def __init__(self):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__init__()'''
            return QNearFieldTarget.AccessMethods()
        def __init__(self):
            '''int QNearFieldTarget.AccessMethods.__init__()'''
            return int()
        def __init__(self):
            '''void QNearFieldTarget.AccessMethods.__init__()'''
        def __bool__(self):
            '''int QNearFieldTarget.AccessMethods.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QNearFieldTarget.AccessMethods.__ne__(QNearFieldTarget.AccessMethods f)'''
            return bool()
        def __eq__(self, f):
            '''bool QNearFieldTarget.AccessMethods.__eq__(QNearFieldTarget.AccessMethods f)'''
            return bool()
        def __invert__(self):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__invert__()'''
            return QNearFieldTarget.AccessMethods()
        def __and__(self, mask):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__and__(int mask)'''
            return QNearFieldTarget.AccessMethods()
        def __xor__(self, f):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__xor__(QNearFieldTarget.AccessMethods f)'''
            return QNearFieldTarget.AccessMethods()
        def __xor__(self, f):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__xor__(int f)'''
            return QNearFieldTarget.AccessMethods()
        def __or__(self, f):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__or__(QNearFieldTarget.AccessMethods f)'''
            return QNearFieldTarget.AccessMethods()
        def __or__(self, f):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__or__(int f)'''
            return QNearFieldTarget.AccessMethods()
        def __int__(self):
            '''int QNearFieldTarget.AccessMethods.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__ixor__(QNearFieldTarget.AccessMethods f)'''
            return QNearFieldTarget.AccessMethods()
        def __ior__(self, f):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__ior__(QNearFieldTarget.AccessMethods f)'''
            return QNearFieldTarget.AccessMethods()
        def __iand__(self, mask):
            '''QNearFieldTarget.AccessMethods QNearFieldTarget.AccessMethods.__iand__(int mask)'''
            return QNearFieldTarget.AccessMethods()


class QQmlNdefRecord(QObject):
    """"""
    # Enum QQmlNdefRecord.TypeNameFormat
    Empty = 0
    NfcRtd = 0
    Mime = 0
    Uri = 0
    ExternalRtd = 0
    Unknown = 0

    def __init__(self, parent = None):
        '''void QQmlNdefRecord.__init__(QObject parent = None)'''
    def __init__(self, record, parent = None):
        '''void QQmlNdefRecord.__init__(QNdefRecord record, QObject parent = None)'''
    recordChanged = pyqtSignal() # void recordChanged() - signal
    typeNameFormatChanged = pyqtSignal() # void typeNameFormatChanged() - signal
    typeChanged = pyqtSignal() # void typeChanged() - signal
    def setRecord(self, record):
        '''void QQmlNdefRecord.setRecord(QNdefRecord record)'''
    def record(self):
        '''QNdefRecord QQmlNdefRecord.record()'''
        return QNdefRecord()
    def typeNameFormat(self):
        '''QQmlNdefRecord.TypeNameFormat QQmlNdefRecord.typeNameFormat()'''
        return QQmlNdefRecord.TypeNameFormat()
    def setTypeNameFormat(self, typeNameFormat):
        '''void QQmlNdefRecord.setTypeNameFormat(QQmlNdefRecord.TypeNameFormat typeNameFormat)'''
    def setType(self, t):
        '''void QQmlNdefRecord.setType(str t)'''
    def type(self):
        '''str QQmlNdefRecord.type()'''
        return str()





# AUTO-GENERATED FILE -- DO NOT EDIT

""" Operator interface.

This module exports a set of functions implemented in C corresponding
to the intrinsic operators of Python.  For example, operator.add(x, y)
is equivalent to the expression x+y.  The function names are those
used for special methods; variants without leading and trailing
'__' are also provided for convenience. """

def __abs__(a):
  """ abs(a) -- Same as abs(a). """
  return None

def __add__(a, b):
  """ add(a, b) -- Same as a + b. """
  return None

def __and__(a, b):
  """ and_(a, b) -- Same as a & b. """
  return None

def __concat__(a, b):
  """ concat(a, b) -- Same as a + b, for a and b sequences. """
  return None

def __contains__(a, b):
  """ contains(a, b) -- Same as b in a (note reversed operands). """
  return None

def __delitem__(a, b):
  """ delitem(a, b) -- Same as del a[b]. """
  return None

def __delslice__(a, b, c):
  """ delslice(a, b, c) -- Same as del a[b:c]. """
  return None

def __div__(a, b):
  """ div(a, b) -- Same as a / b when __future__.division is not in effect. """
  return None

def __eq__(a, b):
  """ eq(a, b) -- Same as a==b. """
  return None

def __floordiv__(a, b):
  """ floordiv(a, b) -- Same as a // b. """
  return None

def __ge__(a, b):
  """ ge(a, b) -- Same as a>=b. """
  return None

def __getitem__(a, b):
  """ getitem(a, b) -- Same as a[b]. """
  return None

def __getslice__(a, b, c):
  """ getslice(a, b, c) -- Same as a[b:c]. """
  return None

def __gt__(a, b):
  """ gt(a, b) -- Same as a>b. """
  return None

def __iadd__(a, b):
  """ a = iadd(a, b) -- Same as a += b. """
  return None

def __iand__(a, b):
  """ a = iand(a, b) -- Same as a &= b. """
  return None

def __iconcat__(a, b):
  """ a = iconcat(a, b) -- Same as a += b, for a and b sequences. """
  return None

def __idiv__(a, b):
  """ a = idiv(a, b) -- Same as a /= b when __future__.division is not in effect. """
  return None

def __ifloordiv__(a, b):
  """ a = ifloordiv(a, b) -- Same as a //= b. """
  return None

def __ilshift__(a, b):
  """ a = ilshift(a, b) -- Same as a <<= b. """
  return None

def __imod__(a, b):
  """ a = imod(a, b) -- Same as a %= b. """
  return None

def __imul__(a, b):
  """ a = imul(a, b) -- Same as a *= b. """
  return None

def __index__(a):
  """ index(a) -- Same as a.__index__() """
  return None

def __inv__(a):
  """ inv(a) -- Same as ~a. """
  return None

def __invert__(a):
  """ invert(a) -- Same as ~a. """
  return None

def __ior__(a, b):
  """ a = ior(a, b) -- Same as a |= b. """
  return None

def __ipow__(a, b):
  """ a = ipow(a, b) -- Same as a **= b. """
  return None

def __irepeat__(a, b):
  """ a = irepeat(a, b) -- Same as a *= b, where a is a sequence, and b is an integer. """
  return 1

def __irshift__(a, b):
  """ a = irshift(a, b) -- Same as a >>= b. """
  return None

def __isub__(a, b):
  """ a = isub(a, b) -- Same as a -= b. """
  return None

def __itruediv__(a, b):
  """ a = itruediv(a, b) -- Same as a /= b when __future__.division is in effect. """
  return None

def __ixor__(a, b):
  """ a = ixor(a, b) -- Same as a ^= b. """
  return None

def __le__(a, b):
  """ le(a, b) -- Same as a<=b. """
  return None

def __lshift__(a, b):
  """ lshift(a, b) -- Same as a << b. """
  return None

def __lt__(a, b):
  """ lt(a, b) -- Same as a<b. """
  return None

def __mod__(a, b):
  """ mod(a, b) -- Same as a % b. """
  return None

def __mul__(a, b):
  """ mul(a, b) -- Same as a * b. """
  return None

def __ne__(a, b):
  """ ne(a, b) -- Same as a!=b. """
  return None

def __neg__(a):
  """ neg(a) -- Same as -a. """
  return None

def __not__(a):
  """ not_(a) -- Same as not a. """
  return None

def __or__(a, b):
  """ or_(a, b) -- Same as a | b. """
  return None

__package__ = None

def __pos__(a):
  """ pos(a) -- Same as +a. """
  return None

def __pow__(a, b):
  """ pow(a, b) -- Same as a ** b. """
  return None

def __repeat__(a, b):
  """ repeat(a, b) -- Return a * b, where a is a sequence, and b is an integer. """
  return 1

def __rshift__(a, b):
  """ rshift(a, b) -- Same as a >> b. """
  return None

def __setitem__(a, b, c):
  """ setitem(a, b, c) -- Same as a[b] = c. """
  return None

def __setslice__(a, b, c, d):
  """ setslice(a, b, c, d) -- Same as a[b:c] = d. """
  return None

def __sub__(a, b):
  """ sub(a, b) -- Same as a - b. """
  return None

def __truediv__(a, b):
  """ truediv(a, b) -- Same as a / b when __future__.division is in effect. """
  return None

def __xor__(a, b):
  """ xor(a, b) -- Same as a ^ b. """
  return None

def abs(a):
  """ abs(a) -- Same as abs(a). """
  return None

def add(a, b):
  """ add(a, b) -- Same as a + b. """
  return None

def and_(a, b):
  """ and_(a, b) -- Same as a & b. """
  return None

class attrgetter(object):
  """ attrgetter(attr, ...) --> attrgetter object
  
  Return a callable object that fetches the given attribute(s) from its operand.
  After, f=attrgetter('name'), the call f(r) returns r.name.
  After, g=attrgetter('name', 'date'), the call g(r) returns (r.name, r.date).
  After, h=attrgetter('name.first', 'name.last'), the call h(r) returns
  (r.name.first, r.name.last). """

  pass

def concat(a, b):
  """ concat(a, b) -- Same as a + b, for a and b sequences. """
  return None

def contains(a, b):
  """ contains(a, b) -- Same as b in a (note reversed operands). """
  return None

def countOf(a, b):
  """ countOf(a, b) -- Return the number of times b occurs in a. """
  return None

def delitem(a, b):
  """ delitem(a, b) -- Same as del a[b]. """
  return None

def delslice(a, b, c):
  """ delslice(a, b, c) -- Same as del a[b:c]. """
  return None

def div(a, b):
  """ div(a, b) -- Same as a / b when __future__.division is not in effect. """
  return None

def eq(a, b):
  """ eq(a, b) -- Same as a==b. """
  return None

def floordiv(a, b):
  """ floordiv(a, b) -- Same as a // b. """
  return None

def ge(a, b):
  """ ge(a, b) -- Same as a>=b. """
  return None

def getitem(a, b):
  """ getitem(a, b) -- Same as a[b]. """
  return None

def getslice(a, b, c):
  """ getslice(a, b, c) -- Same as a[b:c]. """
  return None

def gt(a, b):
  """ gt(a, b) -- Same as a>b. """
  return None

def iadd(a, b):
  """ a = iadd(a, b) -- Same as a += b. """
  return None

def iand(a, b):
  """ a = iand(a, b) -- Same as a &= b. """
  return None

def iconcat(a, b):
  """ a = iconcat(a, b) -- Same as a += b, for a and b sequences. """
  return None

def idiv(a, b):
  """ a = idiv(a, b) -- Same as a /= b when __future__.division is not in effect. """
  return None

def ifloordiv(a, b):
  """ a = ifloordiv(a, b) -- Same as a //= b. """
  return None

def ilshift(a, b):
  """ a = ilshift(a, b) -- Same as a <<= b. """
  return None

def imod(a, b):
  """ a = imod(a, b) -- Same as a %= b. """
  return None

def imul(a, b):
  """ a = imul(a, b) -- Same as a *= b. """
  return None

def index(a):
  """ index(a) -- Same as a.__index__() """
  return None

def indexOf(a, b):
  """ indexOf(a, b) -- Return the first index of b in a. """
  return None

def inv(a):
  """ inv(a) -- Same as ~a. """
  return None

def invert(a):
  """ invert(a) -- Same as ~a. """
  return None

def ior(a, b):
  """ a = ior(a, b) -- Same as a |= b. """
  return None

def ipow(a, b):
  """ a = ipow(a, b) -- Same as a **= b. """
  return None

def irepeat(a, b):
  """ a = irepeat(a, b) -- Same as a *= b, where a is a sequence, and b is an integer. """
  return 1

def irshift(a, b):
  """ a = irshift(a, b) -- Same as a >>= b. """
  return None

def isCallable(a):
  """ isCallable(a) -- Same as callable(a). """
  return None

def isMappingType(a):
  """ isMappingType(a) -- Return True if a has a mapping type, False otherwise. """
  return None

def isNumberType(a):
  """ isNumberType(a) -- Return True if a has a numeric type, False otherwise. """
  return None

def isSequenceType(a):
  """ isSequenceType(a) -- Return True if a has a sequence type, False otherwise. """
  return None

def is_(a, b):
  """ is_(a, b) -- Same as a is b. """
  return None

def is_not(a, b):
  """ is_not(a, b) -- Same as a is not b. """
  return None

def isub(a, b):
  """ a = isub(a, b) -- Same as a -= b. """
  return None

class itemgetter(object):
  """ itemgetter(item, ...) --> itemgetter object
  
  Return a callable object that fetches the given item(s) from its operand.
  After, f=itemgetter(2), the call f(r) returns r[2].
  After, g=itemgetter(2,5,3), the call g(r) returns (r[2], r[5], r[3]) """

  pass

def itruediv(a, b):
  """ a = itruediv(a, b) -- Same as a /= b when __future__.division is in effect. """
  return None

def ixor(a, b):
  """ a = ixor(a, b) -- Same as a ^= b. """
  return None

def le(a, b):
  """ le(a, b) -- Same as a<=b. """
  return None

def lshift(a, b):
  """ lshift(a, b) -- Same as a << b. """
  return None

def lt(a, b):
  """ lt(a, b) -- Same as a<b. """
  return None

class methodcaller(object):
  """ methodcaller(name, ...) --> methodcaller object
  
  Return a callable object that calls the given method on its operand.
  After, f = methodcaller('name'), the call f(r) returns r.name().
  After, g = methodcaller('name', 'date', foo=1), the call g(r) returns
  r.name('date', foo=1). """

  pass

def mod(a, b):
  """ mod(a, b) -- Same as a % b. """
  return None

def mul(a, b):
  """ mul(a, b) -- Same as a * b. """
  return None

def ne(a, b):
  """ ne(a, b) -- Same as a!=b. """
  return None

def neg(a):
  """ neg(a) -- Same as -a. """
  return None

def not_(a):
  """ not_(a) -- Same as not a. """
  return None

def or_(a, b):
  """ or_(a, b) -- Same as a | b. """
  return None

def pos(a):
  """ pos(a) -- Same as +a. """
  return None

def pow(a, b):
  """ pow(a, b) -- Same as a ** b. """
  return None

def repeat(a, b):
  """ repeat(a, b) -- Return a * b, where a is a sequence, and b is an integer. """
  return 1

def rshift(a, b):
  """ rshift(a, b) -- Same as a >> b. """
  return None

def sequenceIncludes(a, b):
  """ sequenceIncludes(a, b) -- Same as b in a (note reversed operands; deprecated). """
  return None

def setitem(a, b, c):
  """ setitem(a, b, c) -- Same as a[b] = c. """
  return None

def setslice(a, b, c, d):
  """ setslice(a, b, c, d) -- Same as a[b:c] = d. """
  return None

def sub(a, b):
  """ sub(a, b) -- Same as a - b. """
  return None

def truediv(a, b):
  """ truediv(a, b) -- Same as a / b when __future__.division is in effect. """
  return None

def truth(a):
  """ truth(a) -- Return True if a is true, False otherwise. """
  return None

def xor(a, b):
  """ xor(a, b) -- Same as a ^ b. """
  return None




#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Access the implementation of the import statement.


"""
"""
The module was found as a source file.


"""
PY_SOURCE = None
"""
The module was found as a compiled code object file.


"""
PY_COMPILED = None
"""
The module was found as dynamically loadable shared library.


"""
C_EXTENSION = None
"""
The module was found as a package directory.


"""
PKG_DIRECTORY = None
"""
The module was found as a built-in module.


"""
C_BUILTIN = None
"""
The module was found as a frozen module (see :func:`init_frozen`).

The following constant and functions are obsolete; their functionality is
available through :func:`find_module` or :func:`load_module`. They are kept
around for backward compatibility:


"""
PY_FROZEN = None
"""
Unused.


"""
SEARCH_ERROR = None
def get_magic():
	"""
	"""
	pass
	
def get_suffixes():
	"""
	Return a list of 3-element tuples, each describing a particular type of
	module. Each triple has the form ``(suffix, mode, type)``, where *suffix* is
	a string to be appended to the module name to form the filename to search
	for, *mode* is the mode string to pass to the built-in :func:`open` function
	to open the file (this can be ``'r'`` for text files or ``'rb'`` for binary
	files), and *type* is the file type, which has one of the values
	:const:`PY_SOURCE`, :const:`PY_COMPILED`, or :const:`C_EXTENSION`, described
	below.
	
	
	"""
	pass
	
def find_module(name,path):
	"""
	Try to find the module *name*.  If *path* is omitted or ``None``, the list of
	directory names given by ``sys.path`` is searched, but first a few special
	places are searched: the function tries to find a built-in module with the
	given name (:const:`C_BUILTIN`), then a frozen module (:const:`PY_FROZEN`),
	and on some systems some other places are looked in as well (on Windows, it
	looks in the registry which may point to a specific file).
	
	Otherwise, *path* must be a list of directory names; each directory is
	searched for files with any of the suffixes returned by :func:`get_suffixes`
	above.  Invalid names in the list are silently ignored (but all list items
	must be strings).
	
	If search is successful, the return value is a 3-element tuple ``(file,
	pathname, description)``:
	
	*file* is an open file object positioned at the beginning, *pathname* is the
	pathname of the file found, and *description* is a 3-element tuple as
	contained in the list returned by :func:`get_suffixes` describing the kind of
	module found.
	
	If the module does not live in a file, the returned *file* is ``None``,
	*pathname* is the empty string, and the *description* tuple contains empty
	strings for its suffix and mode; the module type is indicated as given in
	parentheses above.  If the search is unsuccessful, :exc:`ImportError` is
	raised.  Other exceptions indicate problems with the arguments or
	environment.
	
	If the module is a package, *file* is ``None``, *pathname* is the package
	path and the last item in the *description* tuple is :const:`PKG_DIRECTORY`.
	
	This function does not handle hierarchical module names (names containing
	dots).  In order to find *P*.*M*, that is, submodule *M* of package *P*, use
	:func:`find_module` and :func:`load_module` to find and load package *P*, and
	then use :func:`find_module` with the *path* argument set to ``P.__path__``.
	When *P* itself has a dotted name, apply this recipe recursively.
	
	
	"""
	pass
	
def load_module(name,file,pathname,description):
	"""
	"""
	pass
	
def new_module(name):
	"""
	Return a new empty module object called *name*.  This object is *not* inserted
	in ``sys.modules``.
	
	
	"""
	pass
	
def lock_held():
	"""
	Return ``True`` if the import lock is currently held, else ``False``. On
	platforms without threads, always return ``False``.
	
	On platforms with threads, a thread executing an import holds an internal lock
	until the import is complete. This lock blocks other threads from doing an
	import until the original import completes, which in turn prevents other threads
	from seeing incomplete module objects constructed by the original thread while
	in the process of completing its import (and the imports, if any, triggered by
	that).
	
	
	"""
	pass
	
def acquire_lock():
	"""
	Acquire the interpreter's import lock for the current thread.  This lock should
	be used by import hooks to ensure thread-safety when importing modules.
	
	Once a thread has acquired the import lock, the same thread may acquire it
	again without blocking; the thread must release it once for each time it has
	acquired it.
	
	On platforms without threads, this function does nothing.
	
	"""
	pass
	
def release_lock():
	"""
	Release the interpreter's import lock. On platforms without threads, this
	function does nothing.
	
	"""
	pass
	
def init_builtin(name):
	"""
	Initialize the built-in module called *name* and return its module object along
	with storing it in ``sys.modules``.  If the module was already initialized, it
	will be initialized *again*.  Re-initialization involves the copying of the
	built-in module's ``__dict__`` from the cached module over the module's entry in
	``sys.modules``.  If there is no built-in module called *name*, ``None`` is
	returned.
	
	
	"""
	pass
	
def init_frozen(name):
	"""
	Initialize the frozen module called *name* and return its module object.  If
	the module was already initialized, it will be initialized *again*.  If there
	is no frozen module called *name*, ``None`` is returned.  (Frozen modules are
	modules written in Python whose compiled byte-code object is incorporated
	into a custom-built Python interpreter by Python's :program:`freeze`
	utility. See :file:`Tools/freeze/` for now.)
	
	
	"""
	pass
	
def is_builtin(name):
	"""
	Return ``1`` if there is a built-in module called *name* which can be
	initialized again.  Return ``-1`` if there is a built-in module called *name*
	which cannot be initialized again (see :func:`init_builtin`).  Return ``0`` if
	there is no built-in module called *name*.
	
	
	"""
	pass
	
def is_frozen(name):
	"""
	Return ``True`` if there is a frozen module (see :func:`init_frozen`) called
	*name*, or ``False`` if there is no such module.
	
	
	"""
	pass
	
def load_compiled(name,pathname,file):
	"""
	"""
	pass
	
def load_dynamic(name,pathname,file):
	"""
	Load and initialize a module implemented as a dynamically loadable shared
	library and return its module object.  If the module was already initialized, it
	will be initialized *again*. Re-initialization involves copying the ``__dict__``
	attribute of the cached instance of the module over the value used in the module
	cached in ``sys.modules``.  The *pathname* argument must point to the shared
	library.  The *name* argument is used to construct the name of the
	initialization function: an external C function called ``initname()`` in the
	shared library is called.  The optional *file* argument is ignored.  (Note:
	using shared libraries is highly system dependent, and not all systems support
	it.)
	
	
	"""
	pass
	
def load_source(name,pathname,file):
	"""
	Load and initialize a module implemented as a Python source file and return its
	module object.  If the module was already initialized, it will be initialized
	*again*.  The *name* argument is used to create or access a module object.  The
	*pathname* argument points to the source file.  The *file* argument is the
	source file, open for reading as text, from the beginning. It must currently be
	a real file object, not a user-defined class emulating a file.  Note that if a
	properly matching byte-compiled file (with suffix :file:`.pyc` or :file:`.pyo`)
	exists, it will be used instead of parsing the given source file.
	
	
	"""
	pass
	
class NullImporter:


	"""
	The :class:`NullImporter` type is a :pep:`302` import hook that handles
	non-directory path strings by failing to find any modules.  Calling this type
	with an existing directory or empty string raises :exc:`ImportError`.
	Otherwise, a :class:`NullImporter` instance is returned.
	
	Python adds instances of this type to ``sys.path_importer_cache`` for any path
	entries that are not directories and are not handled by any other path hooks on
	``sys.path_hooks``.  Instances have only one method:
	
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def find_module(self, fullname,path):
		"""
		This method always returns ``None``, indicating that the requested module could
		not be found.
		
		"""
		pass
		
	





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QAbstractVideoBuffer():
    """"""
    # Enum QAbstractVideoBuffer.MapMode
    NotMapped = 0
    ReadOnly = 0
    WriteOnly = 0
    ReadWrite = 0

    # Enum QAbstractVideoBuffer.HandleType
    NoHandle = 0
    GLTextureHandle = 0
    XvShmImageHandle = 0
    CoreImageHandle = 0
    QPixmapHandle = 0
    UserHandle = 0

    def __init__(self, type):
        '''void QAbstractVideoBuffer.__init__(QAbstractVideoBuffer.HandleType type)'''
    def handle(self):
        '''QVariant QAbstractVideoBuffer.handle()'''
        return QVariant()
    def unmap(self):
        '''abstract void QAbstractVideoBuffer.unmap()'''
    def map(self, mode, numBytes, bytesPerLine):
        '''abstract sip.voidptr QAbstractVideoBuffer.map(QAbstractVideoBuffer.MapMode mode, int numBytes, int bytesPerLine)'''
        return sip.voidptr()
    def mapMode(self):
        '''abstract QAbstractVideoBuffer.MapMode QAbstractVideoBuffer.mapMode()'''
        return QAbstractVideoBuffer.MapMode()
    def handleType(self):
        '''QAbstractVideoBuffer.HandleType QAbstractVideoBuffer.handleType()'''
        return QAbstractVideoBuffer.HandleType()


class QAbstractVideoSurface(QObject):
    """"""
    # Enum QAbstractVideoSurface.Error
    NoError = 0
    UnsupportedFormatError = 0
    IncorrectFormatError = 0
    StoppedError = 0
    ResourceError = 0

    def __init__(self, parent = None):
        '''void QAbstractVideoSurface.__init__(QObject parent = None)'''
    def setError(self, error):
        '''void QAbstractVideoSurface.setError(QAbstractVideoSurface.Error error)'''
    supportedFormatsChanged = pyqtSignal() # void supportedFormatsChanged() - signal
    surfaceFormatChanged = pyqtSignal() # void surfaceFormatChanged(const QVideoSurfaceFormatamp;) - signal
    activeChanged = pyqtSignal() # void activeChanged(bool) - signal
    def error(self):
        '''QAbstractVideoSurface.Error QAbstractVideoSurface.error()'''
        return QAbstractVideoSurface.Error()
    def present(self, frame):
        '''abstract bool QAbstractVideoSurface.present(QVideoFrame frame)'''
        return bool()
    def isActive(self):
        '''bool QAbstractVideoSurface.isActive()'''
        return bool()
    def stop(self):
        '''void QAbstractVideoSurface.stop()'''
    def start(self, format):
        '''bool QAbstractVideoSurface.start(QVideoSurfaceFormat format)'''
        return bool()
    def surfaceFormat(self):
        '''QVideoSurfaceFormat QAbstractVideoSurface.surfaceFormat()'''
        return QVideoSurfaceFormat()
    def nearestFormat(self, format):
        '''QVideoSurfaceFormat QAbstractVideoSurface.nearestFormat(QVideoSurfaceFormat format)'''
        return QVideoSurfaceFormat()
    def isFormatSupported(self, format):
        '''bool QAbstractVideoSurface.isFormatSupported(QVideoSurfaceFormat format)'''
        return bool()
    def supportedPixelFormats(self, type = None):
        '''abstract list-of-QVideoFrame.PixelFormat QAbstractVideoSurface.supportedPixelFormats(QAbstractVideoBuffer.HandleType type = QAbstractVideoBuffer.NoHandle)'''
        return [QVideoFrame.PixelFormat()]


class QAudio():
    """"""
    # Enum QAudio.Mode
    AudioInput = 0
    AudioOutput = 0

    # Enum QAudio.State
    ActiveState = 0
    SuspendedState = 0
    StoppedState = 0
    IdleState = 0

    # Enum QAudio.Error
    NoError = 0
    OpenError = 0
    IOError = 0
    UnderrunError = 0
    FatalError = 0



class QAudioDeviceInfo():
    """"""
    def __init__(self):
        '''void QAudioDeviceInfo.__init__()'''
    def __init__(self, other):
        '''void QAudioDeviceInfo.__init__(QAudioDeviceInfo other)'''
    def supportedChannelCounts(self):
        '''list-of-int QAudioDeviceInfo.supportedChannelCounts()'''
        return [int()]
    def supportedSampleRates(self):
        '''list-of-int QAudioDeviceInfo.supportedSampleRates()'''
        return [int()]
    def availableDevices(self, mode):
        '''static list-of-QAudioDeviceInfo QAudioDeviceInfo.availableDevices(QAudio.Mode mode)'''
        return [QAudioDeviceInfo()]
    def defaultOutputDevice(self):
        '''static QAudioDeviceInfo QAudioDeviceInfo.defaultOutputDevice()'''
        return QAudioDeviceInfo()
    def defaultInputDevice(self):
        '''static QAudioDeviceInfo QAudioDeviceInfo.defaultInputDevice()'''
        return QAudioDeviceInfo()
    def supportedSampleTypes(self):
        '''list-of-QAudioFormat.SampleType QAudioDeviceInfo.supportedSampleTypes()'''
        return [QAudioFormat.SampleType()]
    def supportedByteOrders(self):
        '''list-of-QAudioFormat.Endian QAudioDeviceInfo.supportedByteOrders()'''
        return [QAudioFormat.Endian()]
    def supportedSampleSizes(self):
        '''list-of-int QAudioDeviceInfo.supportedSampleSizes()'''
        return [int()]
    def supportedChannels(self):
        '''list-of-int QAudioDeviceInfo.supportedChannels()'''
        return [int()]
    def supportedFrequencies(self):
        '''list-of-int QAudioDeviceInfo.supportedFrequencies()'''
        return [int()]
    def supportedCodecs(self):
        '''QStringList QAudioDeviceInfo.supportedCodecs()'''
        return QStringList()
    def nearestFormat(self, format):
        '''QAudioFormat QAudioDeviceInfo.nearestFormat(QAudioFormat format)'''
        return QAudioFormat()
    def preferredFormat(self):
        '''QAudioFormat QAudioDeviceInfo.preferredFormat()'''
        return QAudioFormat()
    def isFormatSupported(self, format):
        '''bool QAudioDeviceInfo.isFormatSupported(QAudioFormat format)'''
        return bool()
    def deviceName(self):
        '''QString QAudioDeviceInfo.deviceName()'''
        return QString()
    def isNull(self):
        '''bool QAudioDeviceInfo.isNull()'''
        return bool()


class QAudioFormat():
    """"""
    # Enum QAudioFormat.Endian
    BigEndian = 0
    LittleEndian = 0

    # Enum QAudioFormat.SampleType
    Unknown = 0
    SignedInt = 0
    UnSignedInt = 0
    Float = 0

    def __init__(self):
        '''void QAudioFormat.__init__()'''
    def __init__(self, other):
        '''void QAudioFormat.__init__(QAudioFormat other)'''
    def channelCount(self):
        '''int QAudioFormat.channelCount()'''
        return int()
    def setChannelCount(self, channelCount):
        '''void QAudioFormat.setChannelCount(int channelCount)'''
    def sampleRate(self):
        '''int QAudioFormat.sampleRate()'''
        return int()
    def setSampleRate(self, sampleRate):
        '''void QAudioFormat.setSampleRate(int sampleRate)'''
    def sampleType(self):
        '''QAudioFormat.SampleType QAudioFormat.sampleType()'''
        return QAudioFormat.SampleType()
    def setSampleType(self, sampleType):
        '''void QAudioFormat.setSampleType(QAudioFormat.SampleType sampleType)'''
    def byteOrder(self):
        '''QAudioFormat.Endian QAudioFormat.byteOrder()'''
        return QAudioFormat.Endian()
    def setByteOrder(self, byteOrder):
        '''void QAudioFormat.setByteOrder(QAudioFormat.Endian byteOrder)'''
    def codec(self):
        '''QString QAudioFormat.codec()'''
        return QString()
    def setCodec(self, codec):
        '''void QAudioFormat.setCodec(QString codec)'''
    def sampleSize(self):
        '''int QAudioFormat.sampleSize()'''
        return int()
    def setSampleSize(self, sampleSize):
        '''void QAudioFormat.setSampleSize(int sampleSize)'''
    def channels(self):
        '''int QAudioFormat.channels()'''
        return int()
    def setChannels(self, channels):
        '''void QAudioFormat.setChannels(int channels)'''
    def frequency(self):
        '''int QAudioFormat.frequency()'''
        return int()
    def setFrequency(self, frequency):
        '''void QAudioFormat.setFrequency(int frequency)'''
    def isValid(self):
        '''bool QAudioFormat.isValid()'''
        return bool()
    def __ne__(self, other):
        '''bool QAudioFormat.__ne__(QAudioFormat other)'''
        return bool()
    def __eq__(self, other):
        '''bool QAudioFormat.__eq__(QAudioFormat other)'''
        return bool()


class QAudioInput(QObject):
    """"""
    def __init__(self, format = QAudioFormat(), parent = None):
        '''void QAudioInput.__init__(QAudioFormat format = QAudioFormat(), QObject parent = None)'''
    def __init__(self, audioDevice, format = QAudioFormat(), parent = None):
        '''void QAudioInput.__init__(QAudioDeviceInfo audioDevice, QAudioFormat format = QAudioFormat(), QObject parent = None)'''
    notify = pyqtSignal() # void notify() - signal
    stateChanged = pyqtSignal() # void stateChanged(QAudio::State) - signal
    def state(self):
        '''QAudio.State QAudioInput.state()'''
        return QAudio.State()
    def error(self):
        '''QAudio.Error QAudioInput.error()'''
        return QAudio.Error()
    def elapsedUSecs(self):
        '''int QAudioInput.elapsedUSecs()'''
        return int()
    def processedUSecs(self):
        '''int QAudioInput.processedUSecs()'''
        return int()
    def notifyInterval(self):
        '''int QAudioInput.notifyInterval()'''
        return int()
    def setNotifyInterval(self, milliSeconds):
        '''void QAudioInput.setNotifyInterval(int milliSeconds)'''
    def periodSize(self):
        '''int QAudioInput.periodSize()'''
        return int()
    def bytesReady(self):
        '''int QAudioInput.bytesReady()'''
        return int()
    def bufferSize(self):
        '''int QAudioInput.bufferSize()'''
        return int()
    def setBufferSize(self, bytes):
        '''void QAudioInput.setBufferSize(int bytes)'''
    def resume(self):
        '''void QAudioInput.resume()'''
    def suspend(self):
        '''void QAudioInput.suspend()'''
    def reset(self):
        '''void QAudioInput.reset()'''
    def stop(self):
        '''void QAudioInput.stop()'''
    def start(self, device):
        '''void QAudioInput.start(QIODevice device)'''
    def start(self):
        '''QIODevice QAudioInput.start()'''
        return QIODevice()
    def format(self):
        '''QAudioFormat QAudioInput.format()'''
        return QAudioFormat()


class QAudioOutput(QObject):
    """"""
    def __init__(self, format = QAudioFormat(), parent = None):
        '''void QAudioOutput.__init__(QAudioFormat format = QAudioFormat(), QObject parent = None)'''
    def __init__(self, audioDevice, format = QAudioFormat(), parent = None):
        '''void QAudioOutput.__init__(QAudioDeviceInfo audioDevice, QAudioFormat format = QAudioFormat(), QObject parent = None)'''
    notify = pyqtSignal() # void notify() - signal
    stateChanged = pyqtSignal() # void stateChanged(QAudio::State) - signal
    def state(self):
        '''QAudio.State QAudioOutput.state()'''
        return QAudio.State()
    def error(self):
        '''QAudio.Error QAudioOutput.error()'''
        return QAudio.Error()
    def elapsedUSecs(self):
        '''int QAudioOutput.elapsedUSecs()'''
        return int()
    def processedUSecs(self):
        '''int QAudioOutput.processedUSecs()'''
        return int()
    def notifyInterval(self):
        '''int QAudioOutput.notifyInterval()'''
        return int()
    def setNotifyInterval(self, milliSeconds):
        '''void QAudioOutput.setNotifyInterval(int milliSeconds)'''
    def periodSize(self):
        '''int QAudioOutput.periodSize()'''
        return int()
    def bytesFree(self):
        '''int QAudioOutput.bytesFree()'''
        return int()
    def bufferSize(self):
        '''int QAudioOutput.bufferSize()'''
        return int()
    def setBufferSize(self, bytes):
        '''void QAudioOutput.setBufferSize(int bytes)'''
    def resume(self):
        '''void QAudioOutput.resume()'''
    def suspend(self):
        '''void QAudioOutput.suspend()'''
    def reset(self):
        '''void QAudioOutput.reset()'''
    def stop(self):
        '''void QAudioOutput.stop()'''
    def start(self, device):
        '''void QAudioOutput.start(QIODevice device)'''
    def start(self):
        '''QIODevice QAudioOutput.start()'''
        return QIODevice()
    def format(self):
        '''QAudioFormat QAudioOutput.format()'''
        return QAudioFormat()


class QVideoFrame():
    """"""
    # Enum QVideoFrame.PixelFormat
    Format_Invalid = 0
    Format_ARGB32 = 0
    Format_ARGB32_Premultiplied = 0
    Format_RGB32 = 0
    Format_RGB24 = 0
    Format_RGB565 = 0
    Format_RGB555 = 0
    Format_ARGB8565_Premultiplied = 0
    Format_BGRA32 = 0
    Format_BGRA32_Premultiplied = 0
    Format_BGR32 = 0
    Format_BGR24 = 0
    Format_BGR565 = 0
    Format_BGR555 = 0
    Format_BGRA5658_Premultiplied = 0
    Format_AYUV444 = 0
    Format_AYUV444_Premultiplied = 0
    Format_YUV444 = 0
    Format_YUV420P = 0
    Format_YV12 = 0
    Format_UYVY = 0
    Format_YUYV = 0
    Format_NV12 = 0
    Format_NV21 = 0
    Format_IMC1 = 0
    Format_IMC2 = 0
    Format_IMC3 = 0
    Format_IMC4 = 0
    Format_Y8 = 0
    Format_Y16 = 0
    Format_User = 0

    # Enum QVideoFrame.FieldType
    ProgressiveFrame = 0
    TopField = 0
    BottomField = 0
    InterlacedFrame = 0

    def __init__(self):
        '''void QVideoFrame.__init__()'''
    def __init__(self, buffer, size, format):
        '''void QVideoFrame.__init__(QAbstractVideoBuffer buffer, QSize size, QVideoFrame.PixelFormat format)'''
    def __init__(self, bytes, size, bytesPerLine, format):
        '''void QVideoFrame.__init__(int bytes, QSize size, int bytesPerLine, QVideoFrame.PixelFormat format)'''
    def __init__(self, image):
        '''void QVideoFrame.__init__(QImage image)'''
    def __init__(self, other):
        '''void QVideoFrame.__init__(QVideoFrame other)'''
    def imageFormatFromPixelFormat(self, format):
        '''static QImage.Format QVideoFrame.imageFormatFromPixelFormat(QVideoFrame.PixelFormat format)'''
        return QImage.Format()
    def pixelFormatFromImageFormat(self, format):
        '''static QVideoFrame.PixelFormat QVideoFrame.pixelFormatFromImageFormat(QImage.Format format)'''
        return QVideoFrame.PixelFormat()
    def setEndTime(self, time):
        '''void QVideoFrame.setEndTime(int time)'''
    def endTime(self):
        '''int QVideoFrame.endTime()'''
        return int()
    def setStartTime(self, time):
        '''void QVideoFrame.setStartTime(int time)'''
    def startTime(self):
        '''int QVideoFrame.startTime()'''
        return int()
    def handle(self):
        '''QVariant QVideoFrame.handle()'''
        return QVariant()
    def mappedBytes(self):
        '''int QVideoFrame.mappedBytes()'''
        return int()
    def bits(self):
        '''sip.voidptr QVideoFrame.bits()'''
        return sip.voidptr()
    def bytesPerLine(self):
        '''int QVideoFrame.bytesPerLine()'''
        return int()
    def unmap(self):
        '''void QVideoFrame.unmap()'''
    def map(self, mode):
        '''bool QVideoFrame.map(QAbstractVideoBuffer.MapMode mode)'''
        return bool()
    def mapMode(self):
        '''QAbstractVideoBuffer.MapMode QVideoFrame.mapMode()'''
        return QAbstractVideoBuffer.MapMode()
    def isWritable(self):
        '''bool QVideoFrame.isWritable()'''
        return bool()
    def isReadable(self):
        '''bool QVideoFrame.isReadable()'''
        return bool()
    def isMapped(self):
        '''bool QVideoFrame.isMapped()'''
        return bool()
    def setFieldType(self):
        '''QVideoFrame.FieldType QVideoFrame.setFieldType()'''
        return QVideoFrame.FieldType()
    def fieldType(self):
        '''QVideoFrame.FieldType QVideoFrame.fieldType()'''
        return QVideoFrame.FieldType()
    def height(self):
        '''int QVideoFrame.height()'''
        return int()
    def width(self):
        '''int QVideoFrame.width()'''
        return int()
    def size(self):
        '''QSize QVideoFrame.size()'''
        return QSize()
    def handleType(self):
        '''QAbstractVideoBuffer.HandleType QVideoFrame.handleType()'''
        return QAbstractVideoBuffer.HandleType()
    def pixelFormat(self):
        '''QVideoFrame.PixelFormat QVideoFrame.pixelFormat()'''
        return QVideoFrame.PixelFormat()
    def isValid(self):
        '''bool QVideoFrame.isValid()'''
        return bool()


class QVideoSurfaceFormat():
    """"""
    # Enum QVideoSurfaceFormat.YCbCrColorSpace
    YCbCr_Undefined = 0
    YCbCr_BT601 = 0
    YCbCr_BT709 = 0
    YCbCr_xvYCC601 = 0
    YCbCr_xvYCC709 = 0
    YCbCr_JPEG = 0

    # Enum QVideoSurfaceFormat.Direction
    TopToBottom = 0
    BottomToTop = 0

    def __init__(self):
        '''void QVideoSurfaceFormat.__init__()'''
    def __init__(self, size, format, type = None):
        '''void QVideoSurfaceFormat.__init__(QSize size, QVideoFrame.PixelFormat format, QAbstractVideoBuffer.HandleType type = QAbstractVideoBuffer.NoHandle)'''
    def __init__(self, format):
        '''void QVideoSurfaceFormat.__init__(QVideoSurfaceFormat format)'''
    def setProperty(self, name, value):
        '''void QVideoSurfaceFormat.setProperty(str name, QVariant value)'''
    def property(self, name):
        '''QVariant QVideoSurfaceFormat.property(str name)'''
        return QVariant()
    def propertyNames(self):
        '''list-of-QByteArray QVideoSurfaceFormat.propertyNames()'''
        return [QByteArray()]
    def sizeHint(self):
        '''QSize QVideoSurfaceFormat.sizeHint()'''
        return QSize()
    def setYCbCrColorSpace(self, colorSpace):
        '''void QVideoSurfaceFormat.setYCbCrColorSpace(QVideoSurfaceFormat.YCbCrColorSpace colorSpace)'''
    def yCbCrColorSpace(self):
        '''QVideoSurfaceFormat.YCbCrColorSpace QVideoSurfaceFormat.yCbCrColorSpace()'''
        return QVideoSurfaceFormat.YCbCrColorSpace()
    def setPixelAspectRatio(self, ratio):
        '''void QVideoSurfaceFormat.setPixelAspectRatio(QSize ratio)'''
    def setPixelAspectRatio(self, width, height):
        '''void QVideoSurfaceFormat.setPixelAspectRatio(int width, int height)'''
    def pixelAspectRatio(self):
        '''QSize QVideoSurfaceFormat.pixelAspectRatio()'''
        return QSize()
    def setFrameRate(self, rate):
        '''void QVideoSurfaceFormat.setFrameRate(float rate)'''
    def frameRate(self):
        '''float QVideoSurfaceFormat.frameRate()'''
        return float()
    def setScanLineDirection(self, direction):
        '''void QVideoSurfaceFormat.setScanLineDirection(QVideoSurfaceFormat.Direction direction)'''
    def scanLineDirection(self):
        '''QVideoSurfaceFormat.Direction QVideoSurfaceFormat.scanLineDirection()'''
        return QVideoSurfaceFormat.Direction()
    def setViewport(self, viewport):
        '''void QVideoSurfaceFormat.setViewport(QRect viewport)'''
    def viewport(self):
        '''QRect QVideoSurfaceFormat.viewport()'''
        return QRect()
    def frameHeight(self):
        '''int QVideoSurfaceFormat.frameHeight()'''
        return int()
    def frameWidth(self):
        '''int QVideoSurfaceFormat.frameWidth()'''
        return int()
    def setFrameSize(self, size):
        '''void QVideoSurfaceFormat.setFrameSize(QSize size)'''
    def setFrameSize(self, width, height):
        '''void QVideoSurfaceFormat.setFrameSize(int width, int height)'''
    def frameSize(self):
        '''QSize QVideoSurfaceFormat.frameSize()'''
        return QSize()
    def handleType(self):
        '''QAbstractVideoBuffer.HandleType QVideoSurfaceFormat.handleType()'''
        return QAbstractVideoBuffer.HandleType()
    def pixelFormat(self):
        '''QVideoFrame.PixelFormat QVideoSurfaceFormat.pixelFormat()'''
        return QVideoFrame.PixelFormat()
    def isValid(self):
        '''bool QVideoSurfaceFormat.isValid()'''
        return bool()
    def __ne__(self, format):
        '''bool QVideoSurfaceFormat.__ne__(QVideoSurfaceFormat format)'''
        return bool()
    def __eq__(self, format):
        '''bool QVideoSurfaceFormat.__eq__(QVideoSurfaceFormat format)'''
        return bool()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QAxBase():
    """"""
    def __init__(self):
        '''void QAxBase.__init__()'''
    def __init__(self):
        '''QAxBase QAxBase.__init__()'''
        return QAxBase()
    def disableEventSink(self):
        '''void QAxBase.disableEventSink()'''
    def disableClassInfo(self):
        '''void QAxBase.disableClassInfo()'''
    def disableMetaObject(self):
        '''void QAxBase.disableMetaObject()'''
    def setControl(self):
        '''str QAxBase.setControl()'''
        return str()
    def clear(self):
        '''void QAxBase.clear()'''
    exception = pyqtSignal() # void exception(int,const QStringamp;,const QStringamp;,const QStringamp;) - signal
    propertyChanged = pyqtSignal() # void propertyChanged(const QStringamp;) - signal
    signal = pyqtSignal() # void signal(const QStringamp;,int,void*) - signal
    def asVariant(self):
        '''QVariant QAxBase.asVariant()'''
        return QVariant()
    def verbs(self):
        '''list-of-str QAxBase.verbs()'''
        return [str()]
    def isNull(self):
        '''bool QAxBase.isNull()'''
        return bool()
    def setPropertyWritable(self):
        '''bool QAxBase.setPropertyWritable()'''
        return bool()
    def propertyWritable(self):
        '''str QAxBase.propertyWritable()'''
        return str()
    def generateDocumentation(self):
        '''str QAxBase.generateDocumentation()'''
        return str()
    def setPropertyBag(self):
        '''dict-of-str-object QAxBase.setPropertyBag()'''
        return {str():object()}
    def propertyBag(self):
        '''dict-of-str-object QAxBase.propertyBag()'''
        return {str():object()}
    def querySubObject(self):
        '''list-of-QVariant QAxBase.querySubObject()'''
        return [QVariant()]
    def querySubObject(self, value1 = QVariant(), value2 = QVariant(), value3 = QVariant(), value4 = QVariant(), value5 = QVariant(), value6 = QVariant(), value7 = QVariant(), value8 = QVariant()):
        '''str QAxBase.querySubObject(QVariant value1 = QVariant(), QVariant value2 = QVariant(), QVariant value3 = QVariant(), QVariant value4 = QVariant(), QVariant value5 = QVariant(), QVariant value6 = QVariant(), QVariant value7 = QVariant(), QVariant value8 = QVariant())'''
        return str()
    def dynamicCall(self):
        '''list-of-QVariant QAxBase.dynamicCall()'''
        return [QVariant()]
    def dynamicCall(self, value1 = QVariant(), value2 = QVariant(), value3 = QVariant(), value4 = QVariant(), value5 = QVariant(), value6 = QVariant(), value7 = QVariant(), value8 = QVariant()):
        '''str QAxBase.dynamicCall(QVariant value1 = QVariant(), QVariant value2 = QVariant(), QVariant value3 = QVariant(), QVariant value4 = QVariant(), QVariant value5 = QVariant(), QVariant value6 = QVariant(), QVariant value7 = QVariant(), QVariant value8 = QVariant())'''
        return str()
    def control(self):
        '''str QAxBase.control()'''
        return str()


class QAxObject(QObject, QAxBase):
    """"""
    def __init__(self, parent = None):
        '''void QAxObject.__init__(QObject parent = None)'''
    def __init__(self, parent = None):
        '''str QAxObject.__init__(QObject parent = None)'''
        return str()
    def connectNotify(self):
        '''QMetaMethod QAxObject.connectNotify()'''
        return QMetaMethod()
    def doVerb(self):
        '''str QAxObject.doVerb()'''
        return str()


class QAxWidget(QWidget, QAxBase):
    """"""
    def __init__(self, parent = None, flags = 0):
        '''void QAxWidget.__init__(QWidget parent = None, Qt.WindowFlags flags = 0)'''
    def __init__(self, parent = None, flags = 0):
        '''str QAxWidget.__init__(QWidget parent = None, Qt.WindowFlags flags = 0)'''
        return str()
    def connectNotify(self):
        '''QMetaMethod QAxWidget.connectNotify()'''
        return QMetaMethod()
    def translateKeyEvent(self):
        '''int QAxWidget.translateKeyEvent()'''
        return int()
    def resizeEvent(self):
        '''QResizeEvent QAxWidget.resizeEvent()'''
        return QResizeEvent()
    def changeEvent(self):
        '''QEvent QAxWidget.changeEvent()'''
        return QEvent()
    def createHostWindow(self):
        '''bool QAxWidget.createHostWindow()'''
        return bool()
    def minimumSizeHint(self):
        '''QSize QAxWidget.minimumSizeHint()'''
        return QSize()
    def sizeHint(self):
        '''QSize QAxWidget.sizeHint()'''
        return QSize()
    def doVerb(self):
        '''str QAxWidget.doVerb()'''
        return str()
    def clear(self):
        '''void QAxWidget.clear()'''





# SPDX-FileCopyrightText: 2024 Jarmo Tiitto <jarmo.tiitto@gmail.com>
# SPDX-License-Identifier: GPL-2.0-or-later

import sys
import types
import math
import copy

# pylint: disable=C0103, R0903, C0115, R1710
# This module implements the kdevPdb's variable machinery and other helpers.


class enumeratorBase():
    '''Enumerate a list of things.
       Sub classes must compute the sequence length for super().__init__(...).
    '''
    def __init__(self, ref, size):
        self.objectref = ref
        self.size = size

    def __len__(self):
        return self.size

    def next(self):
        '''Sub classes must override this method,
           and set self.objectref = None once completed.'''
        self.objectref = None


class namespaceEnumerator(enumeratorBase):
    '''Enumerate a namespace object.'''
    def __init__(self, obj):
        # filter out some uninteresting python internals.
        filtter = ('__builtins__', '__file__', '__name__', '__spec__')
        obj = [(x, y) for x, y in obj if x not in filtter]
        super().__init__(obj, len(obj))

    def next(self):
        for x, y in self.objectref:
            assert isinstance(x, str)
            yield (x, y)
        self.objectref = None


class UnknownType():
    '''Helper type to differentiate getattr() returning NoneType'''


class attributeEnumerator(enumeratorBase):
    '''Enumerate an object attributes with dir() builtin.'''
    def __init__(self, obj):
        # Sort, although KDevelop will sort the generated set differently.
        # The ordering however does help the user to obtain the attributes in
        # a much nicer order if all of the attributes aren't immediately enumerated.
        g = [[], [], [], [], [], []]
        for x in dir(obj):
            try:
                attr = getattr(obj, x, UnknownType)
                if attr is UnknownType:
                    continue
            except Exception:
                continue
            # order callable attributes after non-callable.
            iscallable = callable(attr)
            if len(x) >= 2 and x[:2] == '__':
                g[4 + iscallable].append(x)
            elif x[0] == '_':
                g[2 + iscallable].append(x)
            else:
                g[0 + iscallable].append(x)
        self.attribs = [x for l in g for x in l]
        hint = len(g[0]) + len(g[1])
        self.expandhint = min(10, len(self.attribs)) if hint == 0 else hint
        super().__init__(obj, len(self.attribs))

    def next(self):
        for x in self.attribs:
            yield (x, getattr(self.objectref, x))
        self.objectref = None


class listEnumerator(enumeratorBase):
    '''Enumerate an list() like sequence with enumerate().'''
    def __init__(self, obj):
        super().__init__(obj, len(obj))

    def next(self):
        for i, x in enumerate(self.objectref):
            yield (f'[{i}]', x)
        self.objectref = None


class dictEnumerator(enumeratorBase):
    '''Enumerate an dict() like object.'''
    def __init__(self, obj):
        super().__init__(obj, len(obj) * 2)

    def next(self):
        try:
            for i, x in enumerate(self.objectref.items()):
                yield (f'[{i}].key', x[0])
                yield (f'[{i}].value', x[1])
        except Exception:
            pass
        self.objectref = None


class chunkEnumerator(enumeratorBase):
    '''Enumerate a string like object in MAX_LEN length chunks'''
    MAX_LEN = 100

    def __init__(self, obj):
        super().__init__(obj, math.ceil(len(obj) / chunkEnumerator.MAX_LEN))

    def next(self):
        for i in range(0, len(self.objectref), chunkEnumerator.MAX_LEN):
            chunk = self.objectref[i:i + chunkEnumerator.MAX_LEN]
            yield (f'[{i}..{i + len(chunk) - 1}]', chunk)
        self.objectref = None


class ExceptionInfo():
    '''Hold user viewable exception info'''
    def __init__(self, _exc, _traceback):
        self.exc = _exc
        self.traceback = _traceback


class ExceptionNode():
    def __init__(self, _exc, _traceback):
        self.exc_type = _exc.__class__.__qualname__
        self.exc_value = ExceptionInfo(_exc, _traceback)


class Exceptions():
    '''Hold a list of ExceptionNodes'''
    def __init__(self, _data):
        self.data = _data


class excInfoEnumerator(enumeratorBase):
    def __init__(self, exc):
        super().__init__(exc, 2)

    def next(self):
        yield 'args', self.objectref.exc.args
        yield 'from', self.objectref.traceback
        self.objectref = None


class excNodeEnumerator(enumeratorBase):
    def __init__(self, nodes):
        super().__init__(nodes, len(nodes))

    def next(self):
        for x in self.objectref:
            yield (x.exc_type, x.exc_value)
        self.objectref = None


class Namespace():
    def __init__(self):
        self.label = ""    # namespace's label inserted in handles
        self.names = {}    # mapping of handles into their longnames in self.handles[]
        self.handles = {}  # mapping of longname into the current and old handle
        self.inited = set()  # set of enumerated longnames.


# Reduced set of immutable types. (see copy._copy_immutable())
_skip_shallowcopy = {types.NoneType, int, float, bool, complex, str,
                     type, range, slice, property,
                     types.BuiltinFunctionType, types.EllipsisType,
                     types.NotImplementedType, types.FunctionType, types.CodeType}


def _shallowcopy(value):
    '''Return a shallow copy of a value if possible or identity'''
    cls = type(value)
    if cls in _skip_shallowcopy:
        return value
    # Check for __setstate__ method as such object is likely not safe to copy.
    if hasattr(value, '__setstate__'):
        _skip_shallowcopy.add(cls)
        return value
    try:
        return copy.copy(value)
    except Exception:
        # Not copy-able: add the type to the ignored set of types,
        # to skip handling the exception again.
        _skip_shallowcopy.add(cls)
        return value


def compareValues(a, b):
    '''General non-equal comparison of two values'''
    try:
        changed = a != b
        if isinstance(changed, bool):
            return changed
    except Exception:
        pass


try:
    import numpy
    numpy.set_printoptions(threshold=numpy.inf)

    class ndarrayEnumerator(enumeratorBase):
        '''Decompose numpy.ndarray into a list of sub dimensions'''
        def __init__(self, obj):
            assert isinstance(obj, numpy.ndarray)
            data = [obj[i] for i in range(obj.shape[0])]
            super().__init__(data, len(data))

        def next(self):
            for i, x in enumerate(self.objectref):
                yield (f'[{i}]', x)
            self.objectref = None

    def inspectNumpyArray(obj, gens, handle):
        '''Inspect numpy.ndarray.'''
        if not isinstance(obj, numpy.ndarray):
            return None
        if len(obj.shape) == 1:
            return {'count': 0, 'data': f"{obj}"}
        if len(obj.shape) > 1:
            # peel dimensions off:
            g = ndarrayEnumerator(obj)
            gens[handle] = g.next()
            return {'count': len(g), 'data': f"shape={obj.shape}", 'expandhint': len(g)}
        return {'count': 0, 'data': '<invalid>'}

    def compareNumpyArrays(a, b):
        '''Compare ndarrays'''
        try:
            return not numpy.array_equal(a, b)
        except Exception:
            pass
except ImportError:
    pass


def inspectSimpleValue(obj, *_):
    '''Inspect a simple value with no children'''
    if isinstance(obj, (types.NoneType, int, bool, float)):
        return {'count': 0, 'data': str(obj)}


def inspectMethodOrFunction(obj, *_):
    '''Inspect a method or function type.'''
    try:
        code = obj.__func__.__code__
        if code:
            # Instance method
            return {'count': 0, 'data': f'{obj.__qualname__}'}
    except Exception:
        pass
    try:
        code = obj.__code__
        if code:
            # Function
            return {'count': 0, 'data': f'{obj.__qualname__}'}
    except Exception:
        pass


def inspectExceptions(obj, gens, handle):
    '''Inspect getreturninfo() exception list.'''
    if not isinstance(obj, Exceptions):
        return None
    # This is synthesized by getreturninfo()
    g = excNodeEnumerator(obj.data)
    gens[handle] = g.next()
    return {'count': len(g), 'type': ''}


def inspectExceptionInfo(obj, gens, handle):
    '''Inspect getreturninfo() exception node.'''
    if not isinstance(obj, ExceptionInfo):
        return None
    g = excInfoEnumerator(obj)
    gens[handle] = g.next()
    return {'count': len(g), 'type': '', 'expandhint': 2}


def inspectClass(obj, gens, handle):
    '''Inspect a class type.'''
    try:
        if obj.__class__ is type:
            report = inspectAttributes(obj, gens, handle)
            report['data'] = f'class {obj.__qualname__}'
            return report
    except AttributeError:
        pass


def inspectCallable(obj, *_):
    '''Inspect a callable type.'''
    if callable(obj):
        return {'count': 0, 'data': '<callable>'}


def inspectModuleType(obj, gens, handle):
    '''Inspect a module.'''
    if not isinstance(obj, types.ModuleType):
        return None
    report = inspectAttributes(obj, gens, handle)
    report['data'] = f"module '{obj.__name__}'"
    return report


def inspectDataString(obj, gens, handle):
    '''Inspect a string like data.'''
    if not isinstance(obj, (str, bytes, bytearray, memoryview)):
        return None
    # For shorter than chunkEnumerator.MAX_LEN chars, report a direct value with 'len'.
    # Otherwise, report in chunks as the sequence may be *very* long.
    # (megabytes perhaps even..)
    try:
        report = {'len': len(obj)}
    except TypeError:
        report = {'len': 0}
    if report['len'] > chunkEnumerator.MAX_LEN:
        g = chunkEnumerator(obj)
        gens[handle] = g.next()
        report['count'] = len(g)
        return report
    report['count'] = 0
    if isinstance(obj, (memoryview, bytearray)):
        # repr() doesn't work well for these types.
        report['data'] = repr(bytes(obj))
        return report
    report['data'] = repr(obj)
    return report


def inspectSequence(obj, gens, handle):
    '''Inspect a sequence.'''
    if not isinstance(obj, (list, tuple, set, frozenset)):
        return None
    g = listEnumerator(obj)
    gens[handle] = g.next()
    return {'count': len(g), 'len': len(obj), 'expandhint': 3}


def inspectDict(obj, gens, handle):
    '''Inspect a dictionary.'''
    if not isinstance(obj, dict):
        return None
    g = dictEnumerator(obj)
    gens[handle] = g.next()
    return {'count': len(g), 'len': len(obj), 'expandhint': 2}


def inspectAttributes(obj, gens, handle):
    '''Inspect attributes of obj.'''
    # This works on all nearly object types, if we have no better way to represent the value.
    g = attributeEnumerator(obj)
    gens[handle] = g.next()
    return {'count': len(g), 'expandhint': g.expandhint}


class kdevExprValueMapper():
    def __init__(self):
        self.handleCounter = 0
        # Mapping of handles into the pinned values.
        self.objectsByHandle = {}
        # Mapping of handles into generators.
        self.objectEnumerators = {}
        # All namespace objects.
        self.objectsByNamespace = {}
        self.droppedNamespaces = set()
        self.variableNsids = -3
        # List of inspect() functions.
        # The order is critical, the first that doesn't return None wins.
        self.detectors = [
            inspectSimpleValue,
            inspectMethodOrFunction,
            inspectExceptions,
            inspectExceptionInfo,
            inspectClass,
            inspectCallable,
            inspectModuleType,
            inspectDataString,
            inspectSequence,
            inspectDict,
            inspectAttributes]
        # List of compare() functions.
        self.comparators = [compareValues]

        # Numpy support is optional.
        if getattr(sys.modules[__name__], 'inspectNumpyArray', None):
            self.detectors.insert(1, inspectNumpyArray)
            self.comparators.append(compareNumpyArrays)

    def makeHandle(self):
        '''Make a variable handle.'''
        self.handleCounter += 1
        return self.handleCounter

    def error(self, msg, lnend='\n'):
        raise NotImplementedError("subclass must implement this method.")

    def get_topindex(self):
        raise NotImplementedError("subclass must implement this method.")

    def dropNamespace(self, ns_id):
        '''Cleanup a namespace id'''
        self.droppedNamespaces.add(ns_id)

    def cleanupobjects(self):
        '''Cleanup invalidated state after pausing'''
        self.objectEnumerators.clear()
        # Purge unavailable namespaces.
        for ns_id in self.objectsByNamespace:
            if ns_id > self.get_topindex():
                self.dropNamespace(ns_id)
        # Coarse purge handles (and longnames) that are now unreachable
        # from the possible namespaces.
        reachable = set()
        unreachable = set()
        for ns_id, ns in list(self.objectsByNamespace.items()):
            if ns_id in self.droppedNamespaces:
                unreachable.update(ns.names)
                # Drop the entire namespace object.
                del self.objectsByNamespace[ns_id]
            else:
                reachable.update(ns.names)
        self.droppedNamespaces.clear()
        # Drop handles which are not in reachable.
        unreachable -= reachable
        num_purged = len(unreachable)
        for ptr in unreachable:
            del self.objectsByHandle[ptr]
        # Purge all longnames which have not been initialized/used.
        pinned = len(self.objectsByHandle)
        for ns in self.objectsByNamespace.values():
            for longname, handles in list(ns.handles.items()):
                if longname in ns.inited:
                    continue
                ns.handles.pop(longname, None)
                ns.names.pop(handles[0], None)
                ns.names.pop(handles[1], None)
                self.objectsByHandle.pop(handles[0], None)
                self.objectsByHandle.pop(handles[1], None)
            ns.inited.clear()
        num_purged += pinned - len(self.objectsByHandle)
        return {'purged': num_purged, 'pinned': len(self.objectsByHandle)}

    def updateNamespace(self, items, ns_id, ns_label):
        '''Create a new namespace handle from a list of tuples'''
        ns = self.objectsByNamespace.setdefault(ns_id, Namespace())
        if ns_label in ns.handles:
            handle = ns.handles[ns_label][0]
        else:
            handle = self.makeHandle()
            # Link the handle inside its own namespace.
            ns.handles[ns_label] = [handle, 0]
        ns.label = ns_label
        ns.names[handle] = ns_label
        ns.inited.add(ns_label)
        self.objectsByHandle[handle] = (ns_id, True)
        g = namespaceEnumerator(items)
        self.objectEnumerators[handle] = g.next()
        return len(g), handle

    def enumerateHandle(self, handle, ns_id, do_copy=True):
        '''Enumerate next variable of a handle.'''
        try:
            # try generate the next item.
            objname, value = next(self.objectEnumerators[handle])
        except StopIteration:
            # the generator was exhausted, remove it.
            self.objectEnumerators.pop(handle, None)
            return None
        except KeyError:
            # No generator was set up.
            # (the client likely made an mistake)
            return None

        parent = self.objectsByHandle[handle]
        if len(parent) == 2:
            # The handle refers to a namespace.
            ns = self.objectsByNamespace[parent[0]]
            longname = objname
        else:
            # Build the current longname for value
            assert ns_id in self.objectsByNamespace
            ns = self.objectsByNamespace[ns_id]
            # '/' is used to join child name to the parent name rather than '.' because
            # this makes it possible later to split the longname into its components.
            longname = ns.names[handle] + '/' + objname

        if longname in ns.inited:
            # Already initialized this longname.
            return {'expression': objname, 'ptr': ns.handles[longname][0]}

        handles = ns.handles.get(longname)
        if handles is None:
            # Make a new pair handles.
            # Initially, the other handle will have no pinned value in objectsByHandle.
            handles = [self.makeHandle(), self.makeHandle()]
            ns.handles[longname] = handles
        # Swap the current and previous handles.
        handles[0], handles[1] = handles[1], handles[0]
        # Update the handles[0]'s pinned value with a shallow copy of the value
        # when possible or reference the value as-is.
        newvalue = _shallowcopy(value) if do_copy else value
        self.objectsByHandle[handles[0]] = (newvalue,)
        # Associate the handle[0] with a longname.
        # Although ns.names[handles[1]] is technically able to refer to a different
        # longname than ns.names[handles[0]], I have never observed this happening.
        # Hence the assert:
        assert handles[1] not in ns.names or ns.names[handles[1]] == longname
        ns.names[handles[0]] = longname
        # Mark the longname as initialized.
        ns.inited.add(longname)
        return {'expression': objname, 'ptr': handles[0]}

    def inspectvalue(self, handle, ns_id):
        ''' Determine the variable's value and other details:
            - The 'count' number of children items, if any, and 'type'.
              These fields must exist.
            Optional fields (can be omitted from the response):
            - 'data' provides the displayed value of the variable.
            - 'len' is displayed in place of 'data' as "len=...",
               or as prefix "len=..., " if both are provided.
            - 'expandhint' is how many children, at minimum, the client should enumerate.
               If not reported, this is min(1,count)
            return: {'count': int(), 'type': str(), 'data': str(),
                     'len': int(), 'expandhint': int()}
        '''
        try:
            obj = self.objectsByHandle[handle][0]
        except KeyError:
            # Not found in the table. Respond with "None" to tell the given handle no longer exists.
            return None

        # Compute the changed state.
        changed = False
        if ns_id is not None:
            ns = self.objectsByNamespace[ns_id]
            handles = ns.handles[ns.names[handle]]
            changed = True
            if handles[1] in self.objectsByHandle:
                for cmp in self.comparators:
                    changed = cmp(obj, self.objectsByHandle[handles[1]][0])
                    if changed is not None:
                        break

        for proc in self.detectors:
            ret = proc(obj, self.objectEnumerators, handle)
            if ret is not None:
                ret.setdefault('changed', changed)
                ret.setdefault('type', obj.__class__.__qualname__)
                return ret
        return None

    def evalexpression(self, expr, frame):
        '''Attempts to evaluate an expression in the context of a stack-frame.'''
        # confine the frame.f_globals.__builtins__ a bit.
        fglobals = {}
        fglobals.update(frame.f_globals)
        fbuiltins = {}
        fbuiltins.update(fglobals['__builtins__'])
        fbuiltins.pop('print', None)
        fbuiltins.pop('__import__', None)
        fbuiltins.pop('eval', None)
        fbuiltins.pop('exec', None)
        fbuiltins.pop('compile', None)
        fglobals['__builtins__'] = fbuiltins
        try:
            evaluate_result = frame.evaluate(expr, fglobals, frame.f_locals)
            return {'value': evaluate_result, 'error': False}
        except Exception as e:
            # Log the error.
            self.error(f"{e}")
        return {'error': True}



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""""""
def ascii(object):
	"""
	Returns the same as :func:`repr`.  In Python 3, :func:`repr` will return
	printable Unicode characters unescaped, while :func:`ascii` will always
	backslash-escape them.  Using :func:`future_builtins.ascii` instead of
	:func:`repr` in 2.6 code makes it clear that you need a pure ASCII return
	value.
	
	"""
	pass
	
def filter(function,iterable):
	"""
	Works like :func:`itertools.ifilter`.
	
	"""
	pass
	
def hex(object):
	"""
	Works like the built-in :func:`hex`, but instead of :meth:`__hex__` it will
	use the :meth:`__index__` method on its argument to get an integer that is
	then converted to hexadecimal.
	
	"""
	pass
	
def map(function,iterable,more):
	"""
	Works like :func:`itertools.imap`.
	
	"""
	pass
	
def oct(object):
	"""
	Works like the built-in :func:`oct`, but instead of :meth:`__oct__` it will
	use the :meth:`__index__` method on its argument to get an integer that is
	then converted to octal.
	
	"""
	pass
	



# AUTO-GENERATED FILE -- DO NOT EDIT

""" Python wrapper for Expat parser. """

EXPAT_VERSION = 'expat_2.0.1'

def ErrorString(errno):
  """ ErrorString(errno) -> string
  Returns string error for given number. """
  return ""

class ExpatError(Exception):

  pass

def ParserCreate(encoding=None, namespace_separator=None):
  """ ParserCreate([encoding[, namespace_separator]]) -> parser
  Return a new XML parser object. """
  return None

class XMLParserType(object):
  """ XML parser """

  pass

XML_PARAM_ENTITY_PARSING_ALWAYS = 2
XML_PARAM_ENTITY_PARSING_NEVER = 0
XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE = 1
__package__ = None
__version__ = '2.7.2'

error = ExpatError
errors = None
expat_CAPI = None
features = []
model = None
native_encoding = 'UTF-8'
version_info = ()

